pub trait TransformRequest:
Send
+ Sync
+ Debug
+ Clone {
type Identifier: Send + Sync + Eq + Debug;
type Input: Send + Clone;
type Output: Send + Clone;
// Required methods
fn request_id(&self) -> Self::Identifier;
fn input(&self) -> &Self::Input;
fn get_dyn_configs(&self) -> Vec<(String, Vec<u8>)>;
}Expand description
A trait representing a transformation request in shepherd-rs processing
system. Each transformation request is a request to transform some input
data into an output format. As such, the Input and Output types are
generic, associated types allowing for flexibility in the types of data
being transformed.
Required Associated Types
Required Methods
Sourcefn request_id(&self) -> Self::Identifier
fn request_id(&self) -> Self::Identifier
Returns the unique identifier for the transformation request.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.